/*
 *     jsz.Plotter - a SWING-based Java package for plotting data
 * Copyright (C) 2000 Janek Schwarz <schwarz@informatik.hu-berlin.de>
 *
 *                    This software is dedicated to 
 *                             THE RAMONES
 *                       the best punk band ever.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: DataSet.java,v 1.5 2000/02/03 21:01:25 schwarz Exp $
 */
package jsz.Plotter;

import java.awt.Color;

/**
 * This class represents a x/y-value pair. The pair can have a
 * specific color. If no color is specified, the default value is
 * used.
 *
 * @author Janek Schwarz
 * @version 1.0
 */ 
public class DataSet
{
/**
 * x-value
 */
private double x;

/**
 * y-value
 */
private double y;

/**
 * color
 */
private Color  color = null;

/**
 * Constructt an new instance with x and y value and default color.
 */ 
public DataSet(double x, double y)
{
  this.x = x;
  this.y = y;
}

/**
 * Constructt an new instance with x and y value and color c.
 */ 
public DataSet(double x, double y, Color color)
{
  this.x = x;
  this.y = y;
  this.color = color;
}

/**
 * Get x-value
 */
final public double getX()
{
  return x;
}

/**
 * Get y-value
 */
final public double getY()
{
  return y;
}

/**
 * Get the color. Can be null. In this case use a default color.
 */
final public Color getColor()
{
  return color;
}

/**
 * Set color to c.
 */
final public void setColor(Color c)
{
  this.color = c;
}
};
