/*
 *     jsz.Plotter - a Swing-based Java package for plotting data
 * Copyright (C) 2000  Janek Schwarz <schwarz@informatik.hu-berlin.de>
 *
 *                    This software is dedicated to 
 *                             THE RAMONES
 *                       the best punk band ever.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: IDataSeries.java,v 1.4 2000/02/03 21:01:26 schwarz Exp $
 */
package jsz.Plotter;

import java.awt.Color;
import java.util.Vector;
import java.util.Observer;

/**
 * A Dataseries is basically a collection of x/y value pairs
 * (implemented as {@link jsz.Plotter.DataSet}.
 * {@link java.util.Observable} is used for implementing
 * Observable functionality. 
 */
public interface IDataSeries 
{
/**
 * 'Observable' functionality. Should be implemented using {@link
 * java.util.Observable}. The other classes in the plotter
 * package really depend on it, so if you decide to implement
 * Observable functionality yourself, be careful.
 */
public void addObserver(Observer o);

/**
 * 'Observable' functionality. Should be implemented using {@link
 * java.util.Observable}. The other classes in the plotter
 * packege really depend on it, so if you decide to implement
 * Observable functionality yourself, be careful.
 */
public void deleteObserver(Observer o);

/**
 * Add a new {@link jsz.Plotter.DataSet} to the dataseries.

 * @param ds dataset
 * @return this instance, so you can write something like
 * <pre> dataseries.add(dataSet1).add(dataSet2);</pre>
 *
 * @see #addDataSet(double x, double y)
 * @see #addDataSet(double x, double y, Color c)
 */
public IDataSeries addDataSet(DataSet ds);

/**
 * Create new new {@link jsz.Plotter.DataSet} from x and y and
 * add it.
 *
 * @param x x-value
 * @param y y-value
 * @return this instance, so you can write something like
 * <pre> dataseries.add(dataSet1).add(dataSet2);</pre>
 * @see #addDataSet(double x, double y)
 * @see #addDataSet(DataSet ds)
 */
public IDataSeries addDataSet(double x, double y);

/**
 * Create new new {@link jsz.Plotter.DataSet} from x
 * and y with color c and add it.
 *
 * @param x x-value
 * @param y y-value
 * @param c color
 * @return this instance, so you can write something like
 * <pre> dataseries.add(dataSet1).add(dataSet2);</pre>
 * @see #addDataSet(double x, double y)
 * @see #addDataSet(DataSet ds)
 */
public IDataSeries addDataSet(double x, double y, Color c);

/**
 * get the data
 */
public Vector getData();

/**
 * set default color.
 */
public void  setColor(Color c);

/**
 * Get default color.
 */
public Color getColor();

/**
 * Set the name this dataseries should be associated with
 */
public void   setLegend(String name);

/**
 * Get the name this dataseries should be associated with
 */
public String getLegend();

/**
 * Get minimal x dimension.
 */
public double getXMin();

/**
 * Get maximal x dimension.
 */
public double getXMax();

/**
 * Get minimal y dimension.
 */
public double getYMin();

/**
 * Get maximal y dimension.
 */
public double getYMax();
};
