/*
 *     jsz.Plotter - a Swing-based Java package for plotting data
 * Copyright (C) 2000  Janek Schwarz <schwarz@informatik.hu-berlin.de>
 *
 *                    This software is dedicated to 
 *                             THE RAMONES
 *                       the best punk band ever.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: PlotterTest3.java,v 1.5 2000/02/03 21:01:43 schwarz Exp $
 */
package jsz.Plotter;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.Random;

/*
 * This class demonstrates some features of the
 * jsz.Plotter package:
 *     scrolling
 *     multi-colored plots
 *     user-instantiated legendlabels and -icons.
 */
public class PlotterTest3
{
public static void main(String argv[]) 
{
  try 
    {
      UIManager.setLookAndFeel(
        UIManager.getCrossPlatformLookAndFeelClassName());
    } 
  catch (Exception e) 
    {}

  JFrame frame = new JFrame("PlotterTest");
  LegendPanel legendpanel = new LegendPanel();
  legendpanel.setBorder(BorderFactory.createTitledBorder(
    BorderFactory.createEtchedBorder(), "Legend"));
  ((FlowLayout)legendpanel.getLayout()).setHgap(20);
  
  Plotter plotter = new Plotter(-5.0, // xmin
                                5.0, // xmax
                                -1.0, // ymin
                                2.0, // ymax
                                1.0, // xTicksDistance
                                1.0); // yTicksDistance
  plotter.setBorder(BorderFactory.createTitledBorder(
    BorderFactory.createEtchedBorder(), "Plotter Test"));
  plotter.setSize(new Dimension(200, 200));

  plotter.setTicksAsDottedLines(true);
  plotter.setXticksCaptionStyle(Plotter.MAXIMA);
  plotter.setYticksCaptionStyle(Plotter.MAXIMA_ZERO);
  
  plotter.setXaxisBehaviour(Plotter.SCROLL);
  
  IDataSeries ds              = new DataSeries("Plot 1", Color.black);
  Color       highPerformance = Color.red;
  Color       baseline        = Color.black;
  Color       safety          = Color.green;
  
  plotter.addPlot(ds);
  legendpanel.add(
    new LegendLabel(new LegendIcon(highPerformance), "High-performance"));
  legendpanel.add(
    new LegendLabel(new LegendIcon(baseline), "Baseline"));
  legendpanel.add(
    new LegendLabel(new LegendIcon(safety), "Safety"));
     
  frame.getContentPane().setLayout(new BorderLayout());
  Box box = Box.createVerticalBox();
  box.add(plotter, BorderLayout.CENTER);
  box.add(legendpanel, BorderLayout.SOUTH);
  frame.getContentPane().add(box, BorderLayout.CENTER);

  frame.addWindowListener(new WindowAdapter() {
    public void windowClosing(WindowEvent e) {
      System.exit(0);
    }
    });
  frame.pack();
  frame.setVisible(true);

  Random random = new Random();
  Color color;
  
  for(double i = -5; ; i += .5)
    {
      int rand = (int) (Math.random() * 3);
      
      switch(rand)
        {
        case 0:
          color = highPerformance;
          break;
        case 1:
          color = baseline;
          break;
        default:
          color = safety;
        }
      
      ds.addDataSet(i, 1, color);

      try
        {
          Thread.sleep(500);
        }
      catch(Exception ex)
        {
        }
    }
}
};
